# coding: utf-8

"""
    Managed Ray API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from openapi_client.configuration import Configuration


class ServiceEventVerboseMessageModel(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'timestamp': 'datetime',
        'message': 'str',
        'service_id': 'str',
        'event_id': 'str'
    }

    attribute_map = {
        'timestamp': 'timestamp',
        'message': 'message',
        'service_id': 'service_id',
        'event_id': 'event_id'
    }

    def __init__(self, timestamp=None, message=None, service_id=None, event_id=None, local_vars_configuration=None):  # noqa: E501
        """ServiceEventVerboseMessageModel - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._timestamp = None
        self._message = None
        self._service_id = None
        self._event_id = None
        self.discriminator = None

        self.timestamp = timestamp
        if message is not None:
            self.message = message
        if service_id is not None:
            self.service_id = service_id
        self.event_id = event_id

    @property
    def timestamp(self):
        """Gets the timestamp of this ServiceEventVerboseMessageModel.  # noqa: E501

        The time this verbose event status was created.  # noqa: E501

        :return: The timestamp of this ServiceEventVerboseMessageModel.  # noqa: E501
        :rtype: datetime
        """
        return self._timestamp

    @timestamp.setter
    def timestamp(self, timestamp):
        """Sets the timestamp of this ServiceEventVerboseMessageModel.

        The time this verbose event status was created.  # noqa: E501

        :param timestamp: The timestamp of this ServiceEventVerboseMessageModel.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and timestamp is None:  # noqa: E501
            raise ValueError("Invalid value for `timestamp`, must not be `None`")  # noqa: E501

        self._timestamp = timestamp

    @property
    def message(self):
        """Gets the message of this ServiceEventVerboseMessageModel.  # noqa: E501

        Message of this verbose event status  # noqa: E501

        :return: The message of this ServiceEventVerboseMessageModel.  # noqa: E501
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """Sets the message of this ServiceEventVerboseMessageModel.

        Message of this verbose event status  # noqa: E501

        :param message: The message of this ServiceEventVerboseMessageModel.  # noqa: E501
        :type: str
        """

        self._message = message

    @property
    def service_id(self):
        """Gets the service_id of this ServiceEventVerboseMessageModel.  # noqa: E501

        The id of the Service v2 for this event. Present only for Service events.  # noqa: E501

        :return: The service_id of this ServiceEventVerboseMessageModel.  # noqa: E501
        :rtype: str
        """
        return self._service_id

    @service_id.setter
    def service_id(self, service_id):
        """Sets the service_id of this ServiceEventVerboseMessageModel.

        The id of the Service v2 for this event. Present only for Service events.  # noqa: E501

        :param service_id: The service_id of this ServiceEventVerboseMessageModel.  # noqa: E501
        :type: str
        """

        self._service_id = service_id

    @property
    def event_id(self):
        """Gets the event_id of this ServiceEventVerboseMessageModel.  # noqa: E501

        Id of each verbose event  # noqa: E501

        :return: The event_id of this ServiceEventVerboseMessageModel.  # noqa: E501
        :rtype: str
        """
        return self._event_id

    @event_id.setter
    def event_id(self, event_id):
        """Sets the event_id of this ServiceEventVerboseMessageModel.

        Id of each verbose event  # noqa: E501

        :param event_id: The event_id of this ServiceEventVerboseMessageModel.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and event_id is None:  # noqa: E501
            raise ValueError("Invalid value for `event_id`, must not be `None`")  # noqa: E501

        self._event_id = event_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ServiceEventVerboseMessageModel):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ServiceEventVerboseMessageModel):
            return True

        return self.to_dict() != other.to_dict()
